% AMIM DOCUMENT STYLE 
% Released 01 August 2020 
% Modified 
%    for LaTeX2e
% Author: Mikheil Rukhaia
% Version: 1.0
% Copyright (C) 2020 by VIAM

\ProvidesClass{amim}
\NeedsTeXFormat{LaTeX2e}

%% Load base
\LoadClass[11pt,a4paper,twoside]{article}

%% Load packages
\RequirePackage{amssymb}
\RequirePackage{amsfonts}
\RequirePackage{amsbsy}
\RequirePackage{amsmath}
\RequirePackage{amsthm}
\RequirePackage{etoolbox}
%\RequirePackage{epstopdf}
\RequirePackage{fancyhdr}
\RequirePackage{graphicx}
\RequirePackage{textcase}
\RequirePackage{url}

%% Page layout
\setlength\textwidth      {12.5cm} 
\setlength\textheight     {20cm}
\setlength\headheight     {15pt}
\setlength\topmargin      {0cm}
\setlength\oddsidemargin  {2.5cm} 
\setlength\evensidemargin {2.5cm}

%% Header and footer
\def\@authorrunning{}
\def\authorrunning#1{\def\@authorrunning{#1}}
\def\@titlerunning{}
\def\titlerunning#1{\def\@titlerunning{#1}}
\def\@vol{}
\def\@nom{}
\def\@year{}
\def\nom#1#2#3{\def\@vol{#1}\def\@nom{#2}\def\@year{#3}}

\fancypagestyle{firstpage}{%
\fancyhf{} % clear all six fields
\renewcommand{\headrulewidth}{0pt}
\renewcommand{\footrulewidth}{0pt}
}
\fancypagestyle{followingpage}{%
\fancyhf{} % clear all six fields
\fancyhead[RE]{{\it \@authorrunning}}
\fancyhead[LO]{{\it \@titlerunning}}
\fancyhead[LE,RO]{{\it AMIM Vol.\@vol\ No.\@nom, \@year}}
\fancyfoot[CE,CO]{\thepage}
\renewcommand{\headrulewidth}{0.5pt}
\renewcommand{\footrulewidth}{0pt}
}
\pagestyle{followingpage}

%% Title
\newcounter{@inst}
\def\thanks#1{\def\@thanks{\footnote{#1}}}
\def\institute#1{\gdef\@institute{#1}}

\def\institutename{\par
 \begingroup
 \parskip=\z@
 \parindent=\z@
 \setcounter{@inst}{1}%
 \def\and{\par\stepcounter{@inst}%
 \noindent$^{\the@inst}$\enspace\ignorespaces}%
 \setbox0=\vbox{\def\thanks##1{}\@institute}%
 \ifnum\c@@inst=1\relax
 \else
   \setcounter{footnote}{\c@@inst}%
   \setcounter{@inst}{1}%
   \noindent$^{\the@inst}$\enspace
 \fi
 \ignorespaces
 \@institute\par
 \endgroup}

\def\inst#1{\unskip$^{#1}$}
\def\email#1{{\tt#1}}
% 
\def\maketitle{\newpage\thispagestyle{firstpage}%
  \begingroup
    \global\@topnum\z@% Prevents figures from going at top of page.
    \let\footnotesize\small \let\footnoterule\relax%
    \renewcommand\thefootnote{\@fnsymbol\c@footnote}% change footnote symbol
    \begin{center}%
      {\MakeTextUppercase{\Large\@title}~\@thanks \par}%
      \vspace*{0.3cm}%
      \begin{tabular}[t]{c}%
        \@author
      \end{tabular}\par%
      % author affiliations
      \vspace*{0.5cm}\noindent 
      \institutename
      %
      \vspace*{0.5cm}\noindent 
      \ifdefempty{\@received}{}{(Received \@received;
       \ifdefempty{\@revised}{}{revised \@revised;}
       accepted \@accepted)\par}  
    \end{center}%
    \par\vspace*{0.2cm}
  \endgroup
  % reset all counters
  \setcounter{section}{0}%
  \setcounter{subsection}{0}%
  \setcounter{figure}{0}
  \setcounter{table}{0}
  \setcounter{equation}{0}
  \setcounter{footnote}{0}%
}

%% Generate additional information
\def\@received{}
\def\@revised{}
\def\@accepted{}
\def\received#1#2#3{\def\@received{#1}\def\@revised{#2}\def\@accepted{#3}}


%% Special paragraphs
\newcommand{\namedparagraph}[3][:]{\par
  \indent{\small {\it #2}#1 #3}\par
}  

\def\keywords#1{\namedparagraph{Keywords and phrases}{#1}}

\def\classification#1{\namedparagraph{AMS subject classification (2010)}{#1}}


%% Bibliography
\bibliographystyle{acm}% this style formats @INPROCEEDINGS best
\renewcommand{\@biblabel}[1]{\hfill#1.}% removes [] in bibliography enumeration

%% Theorems  
\theoremstyle{definition}
\newtheorem{definition}{Definition}
\newtheorem{example}{Example}
\newtheorem{remark}{Remark}
\theoremstyle{plain}
\newtheorem{theorem}{Theorem}
\newtheorem{lemma}{Lemma}
\newtheorem{conjecture}{Conjecture}
\newtheorem{corollary}{Corollary}
\newtheorem{proposition}{Proposition}

%% Make quote enviroment italics
\AtBeginEnvironment{quote}{\itshape}

\endinput
